Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/supermerill/SuperSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/slic3r/GUI/OptionsGroup.hpp')
-rw-r--r--src/slic3r/GUI/OptionsGroup.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/slic3r/GUI/OptionsGroup.hpp b/src/slic3r/GUI/OptionsGroup.hpp
index bc068c1ed..9a494d23d 100644
--- a/src/slic3r/GUI/OptionsGroup.hpp
+++ b/src/slic3r/GUI/OptionsGroup.hpp
@@ -143,8 +143,8 @@ public:
// delete all controls from the option group
void clear(bool destroy_custom_ctrl = false);
- // ask for each script option to recompute their value
- void update_script_presets();
+ // ask for each script option to recompute their value. If init is true, it will ask for get/set even if the Field isn't created.
+ void update_script_presets(bool init = false);
Line create_single_option_line(const Option& option, const std::string& path = std::string()) const;
void append_single_option_line(const Option& option, const std::string& path = std::string()) { append_line(create_single_option_line(option, path)); }